summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorruki <[email protected]>2021-02-19 23:38:07 +0800
committerruki <[email protected]>2021-02-19 23:38:07 +0800
commitc830852b9acbfa5cc6b14ddb41e6328c63860c2e (patch)
tree117b1c88966180530a2990a9ce49bb8741bf3d1d
parentbce29072a6fe078db76cf97c33a1ac2dc032d738 (diff)
improve tty colors for win8
-rw-r--r--xmake/core/base/tty.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/xmake/core/base/tty.lua b/xmake/core/base/tty.lua
index 67b0a1fbf..074c6e31a 100644
--- a/xmake/core/base/tty.lua
+++ b/xmake/core/base/tty.lua
@@ -205,8 +205,8 @@ function tty.has_emoji()
local term = tty.term()
local winos = require("base/winos")
- -- before win7? disable it
- if has_emoji == nil and (os.host() == "windows" and winos.version():le("win7")) then
+ -- before win8? disable it
+ if has_emoji == nil and (os.host() == "windows" and winos.version():le("win8")) then
has_emoji = false
end
@@ -257,7 +257,7 @@ function tty.has_color8()
local winos = require("base/winos")
if os.getenv("ANSICON") then
has_color8 = true
- elseif winos.version():le("win7") then
+ elseif winos.version():le("win8") then
has_color8 = false
else
has_color8 = true